You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@tuscany.apache.org by jm...@apache.org on 2006/06/06 22:47:22 UTC

svn commit: r412208 [2/2] - in /incubator/tuscany/sandbox/jboynes/sca: containers/container.groovy/src/main/java/org/apache/tuscany/container/groovy/ containers/container.groovy/src/test/java/org/apache/tuscany/container/groovy/ containers/container.ja...

Modified: incubator/tuscany/sandbox/jboynes/sca/core2/src/main/java/org/apache/tuscany/core/component/scope/RequestScopeObjectFactory.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/sandbox/jboynes/sca/core2/src/main/java/org/apache/tuscany/core/component/scope/RequestScopeObjectFactory.java?rev=412208&r1=412207&r2=412208&view=diff
==============================================================================
--- incubator/tuscany/sandbox/jboynes/sca/core2/src/main/java/org/apache/tuscany/core/component/scope/RequestScopeObjectFactory.java (original)
+++ incubator/tuscany/sandbox/jboynes/sca/core2/src/main/java/org/apache/tuscany/core/component/scope/RequestScopeObjectFactory.java Tue Jun  6 13:47:19 2006
@@ -8,9 +8,9 @@
  *
  * @version $$Rev$$ $$Date$$
  */
-public class RequestScopeObjectFactory implements ObjectFactory<RequestScopeContext> {
+public class RequestScopeObjectFactory implements ObjectFactory<RequestScopeContainer> {
 
-    public RequestScopeContext getInstance() throws ObjectCreationException {
-        return new RequestScopeContext();
+    public RequestScopeContainer getInstance() throws ObjectCreationException {
+        return new RequestScopeContainer();
     }
 }

Modified: incubator/tuscany/sandbox/jboynes/sca/core2/src/main/java/org/apache/tuscany/core/component/scope/ScopeRegistryImpl.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/sandbox/jboynes/sca/core2/src/main/java/org/apache/tuscany/core/component/scope/ScopeRegistryImpl.java?rev=412208&r1=412207&r2=412208&view=diff
==============================================================================
--- incubator/tuscany/sandbox/jboynes/sca/core2/src/main/java/org/apache/tuscany/core/component/scope/ScopeRegistryImpl.java (original)
+++ incubator/tuscany/sandbox/jboynes/sca/core2/src/main/java/org/apache/tuscany/core/component/scope/ScopeRegistryImpl.java Tue Jun  6 13:47:19 2006
@@ -4,7 +4,7 @@
 import java.util.concurrent.ConcurrentHashMap;
 
 import org.apache.tuscany.spi.ObjectFactory;
-import org.apache.tuscany.spi.component.ScopeContext;
+import org.apache.tuscany.spi.component.ScopeContainer;
 import org.apache.tuscany.spi.component.ScopeNotFoundException;
 import org.apache.tuscany.spi.component.ScopeRegistry;
 import org.apache.tuscany.spi.component.WorkContext;
@@ -17,22 +17,22 @@
  */
 public class ScopeRegistryImpl implements ScopeRegistry {
 
-    private final Map<Scope, ScopeContext> scopeCache;
-    private final Map<Scope, ObjectFactory<? extends ScopeContext>> factoryCache;
+    private final Map<Scope, ScopeContainer> scopeCache;
+    private final Map<Scope, ObjectFactory<? extends ScopeContainer>> factoryCache;
     private final WorkContext workContext;
 
     public ScopeRegistryImpl(WorkContext workContext) {
         assert(workContext != null);
-        scopeCache = new ConcurrentHashMap<Scope, ScopeContext>();
-        factoryCache = new ConcurrentHashMap<Scope, ObjectFactory<? extends ScopeContext>>();
+        scopeCache = new ConcurrentHashMap<Scope, ScopeContainer>();
+        factoryCache = new ConcurrentHashMap<Scope, ObjectFactory<? extends ScopeContainer>>();
         this.workContext = workContext;
     }
 
-    public ScopeContext getScopeContext(Scope scope) {
+    public ScopeContainer getScopeContainer(Scope scope) {
         assert Scope.MODULE != scope: "Cannot get MODULE scope from the registry";
-        ScopeContext context = scopeCache.get(scope);
-        if (context == null) {
-            ObjectFactory<? extends ScopeContext> factory = factoryCache.get(scope);
+        ScopeContainer container = scopeCache.get(scope);
+        if (container == null) {
+            ObjectFactory<? extends ScopeContainer> factory = factoryCache.get(scope);
             if (factory == null) {
                 ScopeNotFoundException e = new ScopeNotFoundException("Scope object factory not registered for scope");
                 switch (scope) {
@@ -51,15 +51,15 @@
                 }
                 throw e;
             }
-            context = factory.getInstance();
-            context.setWorkContext(workContext);
-            context.start();
-            scopeCache.put(scope, context);
+            container = factory.getInstance();
+            container.setWorkContext(workContext);
+            container.start();
+            scopeCache.put(scope, container);
         }
-        return context;
+        return container;
     }
 
-    public <T extends ScopeContext> void registerFactory(Scope scope, ObjectFactory<T> factory) {
+    public <T extends ScopeContainer> void registerFactory(Scope scope, ObjectFactory<T> factory) {
         factoryCache.put(scope, factory);
     }
 

Copied: incubator/tuscany/sandbox/jboynes/sca/core2/src/main/java/org/apache/tuscany/core/component/scope/StatelessScopeContainer.java (from r412206, incubator/tuscany/sandbox/jboynes/sca/core2/src/main/java/org/apache/tuscany/core/component/scope/StatelessScopeContext.java)
URL: http://svn.apache.org/viewvc/incubator/tuscany/sandbox/jboynes/sca/core2/src/main/java/org/apache/tuscany/core/component/scope/StatelessScopeContainer.java?p2=incubator/tuscany/sandbox/jboynes/sca/core2/src/main/java/org/apache/tuscany/core/component/scope/StatelessScopeContainer.java&p1=incubator/tuscany/sandbox/jboynes/sca/core2/src/main/java/org/apache/tuscany/core/component/scope/StatelessScopeContext.java&r1=412206&r2=412208&rev=412208&view=diff
==============================================================================
--- incubator/tuscany/sandbox/jboynes/sca/core2/src/main/java/org/apache/tuscany/core/component/scope/StatelessScopeContext.java (original)
+++ incubator/tuscany/sandbox/jboynes/sca/core2/src/main/java/org/apache/tuscany/core/component/scope/StatelessScopeContainer.java Tue Jun  6 13:47:19 2006
@@ -25,13 +25,13 @@
  *
  * @version $Rev$ $Date$
  */
-public class StatelessScopeContext extends AbstractScopeContext {
+public class StatelessScopeContainer extends AbstractScopeContainer {
 
-    public StatelessScopeContext() {
+    public StatelessScopeContainer() {
         this(null);
     }
 
-    public StatelessScopeContext(WorkContext workContext) {
+    public StatelessScopeContainer(WorkContext workContext) {
         super("Stateless scope", workContext);
         assert(workContext != null): "Work context was null";
     }

Propchange: incubator/tuscany/sandbox/jboynes/sca/core2/src/main/java/org/apache/tuscany/core/component/scope/StatelessScopeContainer.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/tuscany/sandbox/jboynes/sca/core2/src/main/java/org/apache/tuscany/core/component/scope/StatelessScopeContainer.java
------------------------------------------------------------------------------
    svn:keywords = Rev Date

Modified: incubator/tuscany/sandbox/jboynes/sca/core2/src/main/java/org/apache/tuscany/core/component/scope/StatelessScopeObjectFactory.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/sandbox/jboynes/sca/core2/src/main/java/org/apache/tuscany/core/component/scope/StatelessScopeObjectFactory.java?rev=412208&r1=412207&r2=412208&view=diff
==============================================================================
--- incubator/tuscany/sandbox/jboynes/sca/core2/src/main/java/org/apache/tuscany/core/component/scope/StatelessScopeObjectFactory.java (original)
+++ incubator/tuscany/sandbox/jboynes/sca/core2/src/main/java/org/apache/tuscany/core/component/scope/StatelessScopeObjectFactory.java Tue Jun  6 13:47:19 2006
@@ -8,9 +8,9 @@
  *
  * @version $$Rev$$ $$Date$$
  */
-public class StatelessScopeObjectFactory implements ObjectFactory<StatelessScopeContext> {
+public class StatelessScopeObjectFactory implements ObjectFactory<StatelessScopeContainer> {
 
-    public StatelessScopeContext getInstance() throws ObjectCreationException {
-        return new StatelessScopeContext();
+    public StatelessScopeContainer getInstance() throws ObjectCreationException {
+        return new StatelessScopeContainer();
     }
 }

Modified: incubator/tuscany/sandbox/jboynes/sca/core2/src/main/java/org/apache/tuscany/core/deployer/DeployerImpl.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/sandbox/jboynes/sca/core2/src/main/java/org/apache/tuscany/core/deployer/DeployerImpl.java?rev=412208&r1=412207&r2=412208&view=diff
==============================================================================
--- incubator/tuscany/sandbox/jboynes/sca/core2/src/main/java/org/apache/tuscany/core/deployer/DeployerImpl.java (original)
+++ incubator/tuscany/sandbox/jboynes/sca/core2/src/main/java/org/apache/tuscany/core/deployer/DeployerImpl.java Tue Jun  6 13:47:19 2006
@@ -17,12 +17,12 @@
 package org.apache.tuscany.core.deployer;
 
 import org.apache.tuscany.core.builder.Connector;
-import org.apache.tuscany.core.component.scope.ModuleScopeContext;
+import org.apache.tuscany.core.component.scope.ModuleScopeContainer;
 import org.apache.tuscany.spi.annotation.Autowire;
 import org.apache.tuscany.spi.builder.Builder;
 import org.apache.tuscany.spi.component.CompositeComponent;
 import org.apache.tuscany.spi.component.SCAObject;
-import org.apache.tuscany.spi.component.ScopeContext;
+import org.apache.tuscany.spi.component.ScopeContainer;
 import org.apache.tuscany.spi.deployer.Deployer;
 import org.apache.tuscany.spi.deployer.DeploymentContext;
 import org.apache.tuscany.spi.loader.Loader;
@@ -56,7 +56,7 @@
     }
 
     public <I extends Implementation<?>> SCAObject<?> deploy(CompositeComponent<?> parent, ComponentDefinition<I> componentDefinition) throws LoaderException {
-        ScopeContext moduleScope = new ModuleScopeContext();
+        ScopeContainer moduleScope = new ModuleScopeContainer();
         DeploymentContext deploymentContext = new DeploymentContext(null, null, moduleScope);
         load(componentDefinition, deploymentContext);
         SCAObject<?> context = build(parent, componentDefinition, deploymentContext);

Modified: incubator/tuscany/sandbox/jboynes/sca/core2/src/main/java/org/apache/tuscany/core/system/builder/SystemComponentBuilder.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/sandbox/jboynes/sca/core2/src/main/java/org/apache/tuscany/core/system/builder/SystemComponentBuilder.java?rev=412208&r1=412207&r2=412208&view=diff
==============================================================================
--- incubator/tuscany/sandbox/jboynes/sca/core2/src/main/java/org/apache/tuscany/core/system/builder/SystemComponentBuilder.java (original)
+++ incubator/tuscany/sandbox/jboynes/sca/core2/src/main/java/org/apache/tuscany/core/system/builder/SystemComponentBuilder.java Tue Jun  6 13:47:19 2006
@@ -23,9 +23,8 @@
 import org.apache.tuscany.spi.QualifiedName;
 import org.apache.tuscany.spi.builder.BuilderConfigException;
 import org.apache.tuscany.spi.builder.ComponentBuilder;
-import org.apache.tuscany.spi.component.Component;
 import org.apache.tuscany.spi.component.CompositeComponent;
-import org.apache.tuscany.spi.component.ScopeContext;
+import org.apache.tuscany.spi.component.ScopeContainer;
 import org.apache.tuscany.spi.component.AtomicComponent;
 import org.apache.tuscany.spi.deployer.DeploymentContext;
 import org.apache.tuscany.spi.model.ComponentDefinition;
@@ -74,11 +73,11 @@
                 }
             }
         }
-        ScopeContext scopeContext = deploymentContext.getModuleScope();
+        ScopeContainer scopeContainer = deploymentContext.getModuleScope();
         SystemAtomicComponent systemContext =
                 new SystemAtomicComponentImpl(componentDefinition.getName(),
                         parent,
-                        scopeContext,
+                        scopeContainer,
                         serviceInterfaces,
                         factory,
                         componentType.isEagerInit(),

Modified: incubator/tuscany/sandbox/jboynes/sca/core2/src/main/java/org/apache/tuscany/core/system/component/SystemAtomicComponentImpl.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/sandbox/jboynes/sca/core2/src/main/java/org/apache/tuscany/core/system/component/SystemAtomicComponentImpl.java?rev=412208&r1=412207&r2=412208&view=diff
==============================================================================
--- incubator/tuscany/sandbox/jboynes/sca/core2/src/main/java/org/apache/tuscany/core/system/component/SystemAtomicComponentImpl.java (original)
+++ incubator/tuscany/sandbox/jboynes/sca/core2/src/main/java/org/apache/tuscany/core/system/component/SystemAtomicComponentImpl.java Tue Jun  6 13:47:19 2006
@@ -18,7 +18,7 @@
 import org.apache.tuscany.core.system.wire.SystemOutboundWire;
 import org.apache.tuscany.spi.ObjectFactory;
 import org.apache.tuscany.spi.component.CompositeComponent;
-import org.apache.tuscany.spi.component.ScopeContext;
+import org.apache.tuscany.spi.component.ScopeContainer;
 import org.apache.tuscany.spi.component.TargetException;
 import org.apache.tuscany.spi.model.Scope;
 import org.apache.tuscany.spi.wire.OutboundWire;
@@ -34,7 +34,7 @@
 
     public SystemAtomicComponentImpl(String name,
                                      CompositeComponent<?> parent,
-                                     ScopeContext scopeContext,
+                                     ScopeContainer scopeContainer,
                                      Class<?> serviceInterface,
                                      ObjectFactory<?> objectFactory,
                                      boolean eagerInit,
@@ -42,13 +42,13 @@
                                      EventInvoker<Object> destroyInvoker,
                                      List<Injector> injectors,
                                      Map<String, Member> members) {
-        super(name, parent, scopeContext, serviceInterface, objectFactory, eagerInit, initInvoker, destroyInvoker, injectors, members, null);
+        super(name, parent, scopeContainer, serviceInterface, objectFactory, eagerInit, initInvoker, destroyInvoker, injectors, members, null);
         scope = Scope.MODULE;
     }
 
     public SystemAtomicComponentImpl(String name,
                                      CompositeComponent<?> parent,
-                                     ScopeContext scopeContext,
+                                     ScopeContainer scopeContainer,
                                      List<Class<?>> serviceInterfaces,
                                      ObjectFactory<?> objectFactory,
                                      boolean eagerInit,
@@ -56,13 +56,13 @@
                                      EventInvoker<Object> destroyInvoker,
                                      List<Injector> injectors,
                                      Map<String, Member> members) {
-        super(name, parent, scopeContext, serviceInterfaces, objectFactory, eagerInit, initInvoker, destroyInvoker, injectors, members, null);
+        super(name, parent, scopeContainer, serviceInterfaces, objectFactory, eagerInit, initInvoker, destroyInvoker, injectors, members, null);
         scope = Scope.MODULE;
     }
 
     @SuppressWarnings("unchecked")
     public T getTargetInstance() throws TargetException {
-        return (T) scopeContext.getInstance(this);
+        return (T) scopeContainer.getInstance(this);
     }
 
     public Object getServiceInstance(String name) throws TargetException {

Modified: incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/component/scope/BasicHttpSessionScopeTestCase.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/component/scope/BasicHttpSessionScopeTestCase.java?rev=412208&r1=412207&r2=412208&view=diff
==============================================================================
--- incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/component/scope/BasicHttpSessionScopeTestCase.java (original)
+++ incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/component/scope/BasicHttpSessionScopeTestCase.java Tue Jun  6 13:47:19 2006
@@ -10,7 +10,7 @@
 import org.apache.tuscany.core.system.component.SystemAtomicComponent;
 import org.apache.tuscany.core.system.component.SystemAtomicComponentImpl;
 import org.apache.tuscany.spi.ObjectFactory;
-import org.apache.tuscany.spi.component.ScopeContext;
+import org.apache.tuscany.spi.component.ScopeContainer;
 import org.apache.tuscany.spi.component.WorkContext;
 
 /**
@@ -24,12 +24,12 @@
 
     public void testLifecycleManagement() throws Exception {
         WorkContext workContext = new WorkContextImpl();
-        HttpSessionScopeContext scopeContext = new HttpSessionScopeContext(workContext);
+        HttpSessionScopeContainer scopeContext = new HttpSessionScopeContainer(workContext);
         scopeContext.start();
         SystemAtomicComponent atomicContext = createContext(scopeContext);
         // start the request
         Object session = new Object();
-        workContext.setIdentifier(HttpSessionScopeContext.HTTP_IDENTIFIER, session);
+        workContext.setIdentifier(HttpSessionScopeContainer.HTTP_IDENTIFIER, session);
         SessionScopeInitDestroyComponent o1 = (SessionScopeInitDestroyComponent) scopeContext.getInstance(atomicContext);
         assertTrue(o1.isInitialized());
         assertFalse(o1.isDestroyed());
@@ -42,18 +42,18 @@
 
     public void testSessionIsolation() throws Exception {
         WorkContext workContext = new WorkContextImpl();
-        HttpSessionScopeContext scopeContext = new HttpSessionScopeContext(workContext);
+        HttpSessionScopeContainer scopeContext = new HttpSessionScopeContainer(workContext);
         scopeContext.start();
 
         SystemAtomicComponent atomicContext = createContext(scopeContext);
 
         Object session1 = new Object();
-        workContext.setIdentifier(HttpSessionScopeContext.HTTP_IDENTIFIER, session1);
+        workContext.setIdentifier(HttpSessionScopeContainer.HTTP_IDENTIFIER, session1);
         SessionScopeInitDestroyComponent o1 = (SessionScopeInitDestroyComponent) scopeContext.getInstance(atomicContext);
         assertTrue(o1.isInitialized());
 
         Object session2 = new Object();
-        workContext.setIdentifier(HttpSessionScopeContext.HTTP_IDENTIFIER, session2);
+        workContext.setIdentifier(HttpSessionScopeContainer.HTTP_IDENTIFIER, session2);
         SessionScopeInitDestroyComponent o2 = (SessionScopeInitDestroyComponent) scopeContext.getInstance(atomicContext);
         assertNotSame(o1, o2);
 
@@ -76,8 +76,8 @@
         super.tearDown();
     }
 
-    private SystemAtomicComponent createContext(ScopeContext scopeContext) {
-        SystemAtomicComponentImpl context = new SystemAtomicComponentImpl("foo", null, scopeContext, SessionScopeInitDestroyComponent.class, factory, false, initInvoker, destroyInvoker, null, null);
+    private SystemAtomicComponent createContext(ScopeContainer scopeContainer) {
+        SystemAtomicComponentImpl context = new SystemAtomicComponentImpl("foo", null, scopeContainer, SessionScopeInitDestroyComponent.class, factory, false, initInvoker, destroyInvoker, null, null);
         context.start();
         return context;
     }

Modified: incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/component/scope/BasicModuleScopeTestCase.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/component/scope/BasicModuleScopeTestCase.java?rev=412208&r1=412207&r2=412208&view=diff
==============================================================================
--- incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/component/scope/BasicModuleScopeTestCase.java (original)
+++ incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/component/scope/BasicModuleScopeTestCase.java Tue Jun  6 13:47:19 2006
@@ -10,7 +10,7 @@
 import org.apache.tuscany.core.system.component.SystemAtomicComponent;
 import org.apache.tuscany.core.system.component.SystemAtomicComponentImpl;
 import org.apache.tuscany.spi.ObjectFactory;
-import org.apache.tuscany.spi.component.ScopeContext;
+import org.apache.tuscany.spi.component.ScopeContainer;
 import org.apache.tuscany.spi.component.WorkContext;
 
 /**
@@ -24,7 +24,7 @@
 
     public void testLifecycleManagement() throws Exception {
         WorkContext workContext = new WorkContextImpl();
-        ModuleScopeContext scopeContext = new ModuleScopeContext(workContext);
+        ModuleScopeContainer scopeContext = new ModuleScopeContainer(workContext);
         scopeContext.start();
         SystemAtomicComponent atomicContext = createContext(scopeContext);
         // start the request
@@ -40,7 +40,7 @@
 
     public void testModuleIsolation() throws Exception {
         WorkContext workContext = new WorkContextImpl();
-        ModuleScopeContext scopeContext = new ModuleScopeContext(workContext);
+        ModuleScopeContainer scopeContext = new ModuleScopeContainer(workContext);
         scopeContext.start();
 
         SystemAtomicComponent atomicContext = createContext(scopeContext);
@@ -68,8 +68,8 @@
         super.tearDown();
     }
 
-    private SystemAtomicComponent createContext(ScopeContext scopeContext) {
-        SystemAtomicComponentImpl context = new SystemAtomicComponentImpl("foo", null, scopeContext, ModuleScopeInitDestroyComponent.class, factory, false, initInvoker, destroyInvoker, null, null);
+    private SystemAtomicComponent createContext(ScopeContainer scopeContainer) {
+        SystemAtomicComponentImpl context = new SystemAtomicComponentImpl("foo", null, scopeContainer, ModuleScopeInitDestroyComponent.class, factory, false, initInvoker, destroyInvoker, null, null);
         context.start();
         return context;
     }

Modified: incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/component/scope/BasicRequestScopeTestCase.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/component/scope/BasicRequestScopeTestCase.java?rev=412208&r1=412207&r2=412208&view=diff
==============================================================================
--- incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/component/scope/BasicRequestScopeTestCase.java (original)
+++ incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/component/scope/BasicRequestScopeTestCase.java Tue Jun  6 13:47:19 2006
@@ -9,7 +9,7 @@
 import org.apache.tuscany.core.system.component.SystemAtomicComponent;
 import org.apache.tuscany.core.system.component.SystemAtomicComponentImpl;
 import org.apache.tuscany.spi.ObjectFactory;
-import org.apache.tuscany.spi.component.ScopeContext;
+import org.apache.tuscany.spi.component.ScopeContainer;
 
 /**
  * @version $$Rev$$ $$Date$$
@@ -21,7 +21,7 @@
     private ObjectFactory<?> factory;
 
     public void testLifecycleManagement() throws Exception {
-        RequestScopeContext scopeContext = new RequestScopeContext(null);
+        RequestScopeContainer scopeContext = new RequestScopeContainer(null);
         scopeContext.start();
         SystemAtomicComponent atomicContext = createContext(scopeContext);
         // start the request
@@ -36,7 +36,7 @@
     }
 
     public void testRequestIsolation() throws Exception {
-        RequestScopeContext scopeContext = new RequestScopeContext(null);
+        RequestScopeContainer scopeContext = new RequestScopeContainer(null);
         scopeContext.start();
 
         SystemAtomicComponent atomicContext = createContext(scopeContext);
@@ -64,8 +64,8 @@
         super.tearDown();
     }
 
-    private SystemAtomicComponent createContext(ScopeContext scopeContext) {
-        SystemAtomicComponentImpl context = new SystemAtomicComponentImpl("foo", null, scopeContext, RequestScopeInitDestroyComponent.class, factory, false, initInvoker, destroyInvoker, null, null);
+    private SystemAtomicComponent createContext(ScopeContainer scopeContainer) {
+        SystemAtomicComponentImpl context = new SystemAtomicComponentImpl("foo", null, scopeContainer, RequestScopeInitDestroyComponent.class, factory, false, initInvoker, destroyInvoker, null, null);
         context.start();
         return context;
     }

Modified: incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/component/scope/BasicStatelessScopeTestCase.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/component/scope/BasicStatelessScopeTestCase.java?rev=412208&r1=412207&r2=412208&view=diff
==============================================================================
--- incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/component/scope/BasicStatelessScopeTestCase.java (original)
+++ incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/component/scope/BasicStatelessScopeTestCase.java Tue Jun  6 13:47:19 2006
@@ -21,7 +21,7 @@
      */
     public void testInstanceManagement() throws Exception {
         WorkContext ctx = new WorkContextImpl();
-        StatelessScopeContext scope = new StatelessScopeContext(ctx);
+        StatelessScopeContainer scope = new StatelessScopeContainer(ctx);
         scope.start();
         SystemAtomicComponent context1 = MockContextFactory.createSystemAtomicContext("comp1", scope, StatelessComponentImpl.class);
         scope.register(context1);
@@ -37,7 +37,7 @@
 
     public void testRegisterContextAfterRequest() throws Exception {
         WorkContext ctx = new WorkContextImpl();
-        StatelessScopeContext scope = new StatelessScopeContext(ctx);
+        StatelessScopeContainer scope = new StatelessScopeContainer(ctx);
 
         scope.start();
         SystemAtomicComponent context1 = MockContextFactory.createSystemAtomicContext("comp1", scope, StatelessComponentImpl.class);
@@ -57,7 +57,7 @@
      */
     public void testSetNullComponents() throws Exception {
         WorkContext ctx = new WorkContextImpl();
-        StatelessScopeContext scope = new StatelessScopeContext(ctx);
+        StatelessScopeContainer scope = new StatelessScopeContainer(ctx);
         scope.start();
         scope.stop();
     }

Modified: incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/component/scope/DependencyLifecycleTestCase.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/component/scope/DependencyLifecycleTestCase.java?rev=412208&r1=412207&r2=412208&view=diff
==============================================================================
--- incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/component/scope/DependencyLifecycleTestCase.java (original)
+++ incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/component/scope/DependencyLifecycleTestCase.java Tue Jun  6 13:47:19 2006
@@ -26,7 +26,7 @@
 
     public void testInitDestroyOrderModuleScope() throws Exception {
         WorkContext ctx = new WorkContextImpl();
-        ModuleScopeContext scopeCtx = new ModuleScopeContext(ctx);
+        ModuleScopeContainer scopeCtx = new ModuleScopeContainer(ctx);
         scopeCtx.start();
         Map<String, AtomicComponent> contexts = MockContextFactory.createWiredContexts("source", OrderedDependentPojoImpl.class,
                 scopeCtx, "target", OrderedInitPojoImpl.class, scopeCtx);
@@ -50,7 +50,7 @@
 
     public void testInitDestroyOrderAfterStartModuleScope() throws Exception {
         WorkContext ctx = new WorkContextImpl();
-        ModuleScopeContext scopeCtx = new ModuleScopeContext(ctx);
+        ModuleScopeContainer scopeCtx = new ModuleScopeContainer(ctx);
         scopeCtx.start();
         Map<String, AtomicComponent> contexts = MockContextFactory.createWiredContexts("source", OrderedDependentPojoImpl.class,
                 scopeCtx, "target", OrderedInitPojoImpl.class, scopeCtx);
@@ -72,7 +72,7 @@
 
     public void testInitDestroyOrderSessionScope() throws Exception {
         WorkContext ctx = new WorkContextImpl();
-        HttpSessionScopeContext scopeCtx = new HttpSessionScopeContext(ctx);
+        HttpSessionScopeContainer scopeCtx = new HttpSessionScopeContainer(ctx);
         scopeCtx.start();
         Object session = new Object();
         Map<String, AtomicComponent> contexts = MockContextFactory.createWiredContexts("source", OrderedDependentPojoImpl.class,
@@ -81,7 +81,7 @@
         AtomicComponent targetComponent = contexts.get("target");
         scopeCtx.register(sourceComponent);
         scopeCtx.register(targetComponent);
-        ctx.setIdentifier(HttpSessionScopeContext.HTTP_IDENTIFIER, session);
+        ctx.setIdentifier(HttpSessionScopeContainer.HTTP_IDENTIFIER, session);
         OrderedDependentPojo source = (OrderedDependentPojo) scopeCtx.getInstance(sourceComponent);
         assertNotNull(source.getPojo());
         assertEquals(2, source.getNumberInstantiated());
@@ -93,14 +93,14 @@
 
     public void testInitDestroyOrderAfterStartSessionScope() throws Exception {
         WorkContext ctx = new WorkContextImpl();
-        HttpSessionScopeContext scopeCtx = new HttpSessionScopeContext(ctx);
+        HttpSessionScopeContainer scopeCtx = new HttpSessionScopeContainer(ctx);
         scopeCtx.start();
         Object session = new Object();
         Map<String, AtomicComponent> contexts = MockContextFactory.createWiredContexts("source", OrderedDependentPojoImpl.class,
                 scopeCtx, "target", OrderedInitPojoImpl.class, scopeCtx);
         AtomicComponent sourceComponent = contexts.get("source");
         AtomicComponent targetComponent = contexts.get("target");
-        ctx.setIdentifier(HttpSessionScopeContext.HTTP_IDENTIFIER, session);
+        ctx.setIdentifier(HttpSessionScopeContainer.HTTP_IDENTIFIER, session);
         scopeCtx.register(sourceComponent);
         scopeCtx.register(targetComponent);
         OrderedDependentPojo source = (OrderedDependentPojo) scopeCtx.getInstance(sourceComponent);
@@ -113,7 +113,7 @@
 
     public void testInitDestroyOrderRequestScope() throws Exception {
         WorkContext ctx = new WorkContextImpl();
-        RequestScopeContext scopeCtx = new RequestScopeContext(ctx);
+        RequestScopeContainer scopeCtx = new RequestScopeContainer(ctx);
         scopeCtx.start();
         scopeCtx.onEvent(new RequestStart(this));
         Map<String, AtomicComponent> contexts = MockContextFactory.createWiredContexts("source", OrderedDependentPojoImpl.class,

Modified: incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/component/scope/HttpSessionScopeInstanceLifecycleTestCase.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/component/scope/HttpSessionScopeInstanceLifecycleTestCase.java?rev=412208&r1=412207&r2=412208&view=diff
==============================================================================
--- incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/component/scope/HttpSessionScopeInstanceLifecycleTestCase.java (original)
+++ incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/component/scope/HttpSessionScopeInstanceLifecycleTestCase.java Tue Jun  6 13:47:19 2006
@@ -24,7 +24,7 @@
 
     public void testInitDestroy() throws Exception {
         WorkContext ctx = new WorkContextImpl();
-        HttpSessionScopeContext scope = new HttpSessionScopeContext(ctx);
+        HttpSessionScopeContainer scope = new HttpSessionScopeContainer(ctx);
         scope.start();
 
         SystemAtomicComponent initDestroyContext = MockContextFactory.createSystemAtomicContext("InitDestroy", scope, RequestScopeInitDestroyComponent.class);
@@ -37,7 +37,7 @@
         destroyOnlyContext.start();
 
         Object session = new Object();
-        ctx.setIdentifier(HttpSessionScopeContext.HTTP_IDENTIFIER, session);
+        ctx.setIdentifier(HttpSessionScopeContainer.HTTP_IDENTIFIER, session);
         scope.onEvent(new HttpSessionStart(this, session));
         RequestScopeInitDestroyComponent initDestroy = (RequestScopeInitDestroyComponent) scope.getInstance(initDestroyContext);
         Assert.assertNotNull(initDestroy);
@@ -64,7 +64,7 @@
 
     public void testDestroyOrder() throws Exception {
         WorkContext ctx = new WorkContextImpl();
-        HttpSessionScopeContext scope = new HttpSessionScopeContext(ctx);
+        HttpSessionScopeContainer scope = new HttpSessionScopeContainer(ctx);
         scope.start();
 
         SystemAtomicComponent oneCtx = MockContextFactory.createSystemAtomicContext("one", scope, OrderedInitPojoImpl.class);
@@ -75,7 +75,7 @@
         scope.register(threeCtx);
 
         Object session = new Object();
-        ctx.setIdentifier(HttpSessionScopeContext.HTTP_IDENTIFIER, session);
+        ctx.setIdentifier(HttpSessionScopeContainer.HTTP_IDENTIFIER, session);
         scope.onEvent(new HttpSessionStart(this, session));
         OrderedInitPojo one = (OrderedInitPojo) scope.getInstance(oneCtx);
         Assert.assertNotNull(one);
@@ -100,7 +100,7 @@
 
     public void testEagerInitDestroyOrder() throws Exception {
         WorkContext ctx = new WorkContextImpl();
-        HttpSessionScopeContext scope = new HttpSessionScopeContext(ctx);
+        HttpSessionScopeContainer scope = new HttpSessionScopeContainer(ctx);
         scope.start();
 
         SystemAtomicComponent oneCtx = MockContextFactory.createSystemAtomicContext("one", scope, OrderedEagerInitPojo.class);
@@ -111,7 +111,7 @@
         scope.register(threeCtx);
 
         Object session = new Object();
-        ctx.setIdentifier(HttpSessionScopeContext.HTTP_IDENTIFIER, session);
+        ctx.setIdentifier(HttpSessionScopeContainer.HTTP_IDENTIFIER, session);
         scope.onEvent(new HttpSessionStart(this, session));
         OrderedEagerInitPojo one = (OrderedEagerInitPojo) scope.getInstance(oneCtx);
         Assert.assertNotNull(one);

Modified: incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/component/scope/HttpSessionScopeRestartTestCase.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/component/scope/HttpSessionScopeRestartTestCase.java?rev=412208&r1=412207&r2=412208&view=diff
==============================================================================
--- incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/component/scope/HttpSessionScopeRestartTestCase.java (original)
+++ incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/component/scope/HttpSessionScopeRestartTestCase.java Tue Jun  6 13:47:19 2006
@@ -20,7 +20,7 @@
 
     public void testRestart() throws Exception {
         WorkContext ctx = new WorkContextImpl();
-        HttpSessionScopeContext scope = new HttpSessionScopeContext(ctx);
+        HttpSessionScopeContainer scope = new HttpSessionScopeContainer(ctx);
         scope.start();
         MethodEventInvoker<Object> initInvoker = new MethodEventInvoker<Object>(HttpSessionScopeRestartTestCase.InitDestroyOnce.class.getMethod("init"));
         MethodEventInvoker<Object> destroyInvoker = new MethodEventInvoker<Object>(HttpSessionScopeRestartTestCase.InitDestroyOnce.class.getMethod("destroy"));
@@ -31,7 +31,7 @@
         context.start();
 
         Object session = new Object();
-        ctx.setIdentifier(HttpSessionScopeContext.HTTP_IDENTIFIER, session);
+        ctx.setIdentifier(HttpSessionScopeContainer.HTTP_IDENTIFIER, session);
         scope.onEvent(new HttpSessionStart(this, session));
         Object instance = context.getServiceInstance();
         assertSame(instance, context.getServiceInstance());

Modified: incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/component/scope/ModuleScopeInstanceLifecycleTestCase.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/component/scope/ModuleScopeInstanceLifecycleTestCase.java?rev=412208&r1=412207&r2=412208&view=diff
==============================================================================
--- incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/component/scope/ModuleScopeInstanceLifecycleTestCase.java (original)
+++ incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/component/scope/ModuleScopeInstanceLifecycleTestCase.java Tue Jun  6 13:47:19 2006
@@ -25,7 +25,7 @@
 
     public void testInitDestroy() throws Exception {
         WorkContext ctx = new WorkContextImpl();
-        ModuleScopeContext scope = new ModuleScopeContext(ctx);
+        ModuleScopeContainer scope = new ModuleScopeContainer(ctx);
         scope.start();
 
         SystemAtomicComponent initDestroyContext = MockContextFactory.createSystemAtomicContext("InitDestroy", scope, ModuleScopeInitDestroyComponent.class);
@@ -63,7 +63,7 @@
 
     public void testDestroyOrder() throws Exception {
         WorkContext ctx = new WorkContextImpl();
-        ModuleScopeContext scope = new ModuleScopeContext(ctx);
+        ModuleScopeContainer scope = new ModuleScopeContainer(ctx);
         scope.start();
 
         SystemAtomicComponent oneCtx = MockContextFactory.createSystemAtomicContext("one", scope, OrderedInitPojoImpl.class);
@@ -97,7 +97,7 @@
 
     public void testEagerInitDestroyOrder() throws Exception {
         WorkContext ctx = new WorkContextImpl();
-        ModuleScopeContext scope = new ModuleScopeContext(ctx);
+        ModuleScopeContainer scope = new ModuleScopeContainer(ctx);
         scope.start();
 
         SystemAtomicComponent oneCtx = MockContextFactory.createSystemAtomicContext("one", scope, OrderedEagerInitPojo.class);

Modified: incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/component/scope/ModuleScopeRestartTestCase.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/component/scope/ModuleScopeRestartTestCase.java?rev=412208&r1=412207&r2=412208&view=diff
==============================================================================
--- incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/component/scope/ModuleScopeRestartTestCase.java (original)
+++ incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/component/scope/ModuleScopeRestartTestCase.java Tue Jun  6 13:47:19 2006
@@ -21,7 +21,7 @@
 
     public void testRestart() throws Exception {
         WorkContext ctx = new WorkContextImpl();
-        ModuleScopeContext scope = new ModuleScopeContext(ctx);
+        ModuleScopeContainer scope = new ModuleScopeContainer(ctx);
         scope.start();
         MethodEventInvoker<Object> initInvoker = new MethodEventInvoker<Object>(InitDestroyOnce.class.getMethod("init"));
         MethodEventInvoker<Object> destroyInvoker = new MethodEventInvoker<Object>(InitDestroyOnce.class.getMethod("destroy"));

Modified: incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/component/scope/RequestScopeInstanceLifecycleTestCase.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/component/scope/RequestScopeInstanceLifecycleTestCase.java?rev=412208&r1=412207&r2=412208&view=diff
==============================================================================
--- incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/component/scope/RequestScopeInstanceLifecycleTestCase.java (original)
+++ incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/component/scope/RequestScopeInstanceLifecycleTestCase.java Tue Jun  6 13:47:19 2006
@@ -24,7 +24,7 @@
 
     public void testInitDestroy() throws Exception {
         WorkContext ctx = new WorkContextImpl();
-        RequestScopeContext scope = new RequestScopeContext(ctx);
+        RequestScopeContainer scope = new RequestScopeContainer(ctx);
         scope.start();
 
         SystemAtomicComponent initDestroyContext = MockContextFactory.createSystemAtomicContext("InitDestroy", scope, RequestScopeInitDestroyComponent.class);
@@ -62,7 +62,7 @@
 
     public void testDestroyOrder() throws Exception {
         WorkContext ctx = new WorkContextImpl();
-        RequestScopeContext scope = new RequestScopeContext(ctx);
+        RequestScopeContainer scope = new RequestScopeContainer(ctx);
         scope.start();
 
         SystemAtomicComponent oneCtx = MockContextFactory.createSystemAtomicContext("one", scope, OrderedInitPojoImpl.class);
@@ -96,7 +96,7 @@
 
     public void testEagerInitDestroyOrder() throws Exception {
         WorkContext ctx = new WorkContextImpl();
-        RequestScopeContext scope = new RequestScopeContext(ctx);
+        RequestScopeContainer scope = new RequestScopeContainer(ctx);
         scope.start();
 
         SystemAtomicComponent oneCtx = MockContextFactory.createSystemAtomicContext("one", scope, OrderedEagerInitPojo.class);

Modified: incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/component/scope/RequestScopeRestartTestCase.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/component/scope/RequestScopeRestartTestCase.java?rev=412208&r1=412207&r2=412208&view=diff
==============================================================================
--- incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/component/scope/RequestScopeRestartTestCase.java (original)
+++ incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/component/scope/RequestScopeRestartTestCase.java Tue Jun  6 13:47:19 2006
@@ -20,7 +20,7 @@
 
     public void testRestart() throws Exception {
         WorkContext ctx = new WorkContextImpl();
-        RequestScopeContext scope = new RequestScopeContext(ctx);
+        RequestScopeContainer scope = new RequestScopeContainer(ctx);
         scope.start();
         MethodEventInvoker<Object> initInvoker = new MethodEventInvoker<Object>(RequestScopeRestartTestCase.InitDestroyOnce.class.getMethod("init"));
         MethodEventInvoker<Object> destroyInvoker = new MethodEventInvoker<Object>(RequestScopeRestartTestCase.InitDestroyOnce.class.getMethod("destroy"));

Modified: incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/component/scope/ScopeRegistryTestCase.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/component/scope/ScopeRegistryTestCase.java?rev=412208&r1=412207&r2=412208&view=diff
==============================================================================
--- incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/component/scope/ScopeRegistryTestCase.java (original)
+++ incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/component/scope/ScopeRegistryTestCase.java Tue Jun  6 13:47:19 2006
@@ -2,7 +2,7 @@
 
 import junit.framework.TestCase;
 import org.apache.tuscany.core.component.WorkContextImpl;
-import org.apache.tuscany.spi.component.ScopeContext;
+import org.apache.tuscany.spi.component.ScopeContainer;
 import org.apache.tuscany.spi.component.ScopeRegistry;
 import org.apache.tuscany.spi.component.WorkContext;
 import org.apache.tuscany.spi.model.Scope;
@@ -18,12 +18,12 @@
         ScopeRegistry scopeRegistry = new ScopeRegistryImpl(workContext);
         scopeRegistry.registerFactory(Scope.REQUEST, new RequestScopeObjectFactory());
         scopeRegistry.registerFactory(Scope.SESSION, new HttpSessionScopeObjectFactory());
-        ScopeContext request = scopeRegistry.getScopeContext(Scope.REQUEST);
-        assertTrue(request instanceof RequestScopeContext);
-        assertSame(request, scopeRegistry.getScopeContext(Scope.REQUEST));
-        ScopeContext session = scopeRegistry.getScopeContext(Scope.SESSION);
-        assertTrue(session instanceof HttpSessionScopeContext);
-        assertSame(session, scopeRegistry.getScopeContext(Scope.SESSION));
+        ScopeContainer request = scopeRegistry.getScopeContainer(Scope.REQUEST);
+        assertTrue(request instanceof RequestScopeContainer);
+        assertSame(request, scopeRegistry.getScopeContainer(Scope.REQUEST));
+        ScopeContainer session = scopeRegistry.getScopeContainer(Scope.SESSION);
+        assertTrue(session instanceof HttpSessionScopeContainer);
+        assertSame(session, scopeRegistry.getScopeContainer(Scope.SESSION));
         assertNotSame(request, session);
     }
 }

Modified: incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/integration/system/builder/AutowireBuilderTestcase.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/integration/system/builder/AutowireBuilderTestcase.java?rev=412208&r1=412207&r2=412208&view=diff
==============================================================================
--- incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/integration/system/builder/AutowireBuilderTestcase.java (original)
+++ incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/integration/system/builder/AutowireBuilderTestcase.java Tue Jun  6 13:47:19 2006
@@ -6,7 +6,7 @@
 import org.apache.tuscany.core.component.WorkContextImpl;
 import org.apache.tuscany.core.component.event.CompositeStart;
 import org.apache.tuscany.core.component.event.CompositeStop;
-import org.apache.tuscany.core.component.scope.ModuleScopeContext;
+import org.apache.tuscany.core.component.scope.ModuleScopeContainer;
 import org.apache.tuscany.core.mock.component.Source;
 import org.apache.tuscany.core.mock.component.Target;
 import org.apache.tuscany.core.mock.factories.MockComponentFactory;
@@ -18,7 +18,7 @@
 import org.apache.tuscany.core.system.model.SystemImplementation;
 import org.apache.tuscany.spi.component.AtomicComponent;
 import org.apache.tuscany.spi.component.Reference;
-import org.apache.tuscany.spi.component.ScopeContext;
+import org.apache.tuscany.spi.component.ScopeContainer;
 import org.apache.tuscany.spi.component.WorkContext;
 import org.apache.tuscany.spi.deployer.DeploymentContext;
 import org.apache.tuscany.spi.model.BoundReferenceDefinition;
@@ -38,7 +38,7 @@
      */
     public void testComponentToReference() throws Exception {
         WorkContext work = new WorkContextImpl();
-        ScopeContext scope = new ModuleScopeContext(work);
+        ScopeContainer scope = new ModuleScopeContainer(work);
         scope.start();
 
         Connector connector = new ConnectorImpl();
@@ -83,7 +83,7 @@
      */
     public void testComponentToComponent() throws Exception {
         WorkContext work = new WorkContextImpl();
-        ScopeContext scope = new ModuleScopeContext(work);
+        ScopeContainer scope = new ModuleScopeContainer(work);
         scope.start();
 
         SystemComponentBuilder componentBuilder = new SystemComponentBuilder();

Modified: incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/integration/system/builder/SystemBuildersTestCase.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/integration/system/builder/SystemBuildersTestCase.java?rev=412208&r1=412207&r2=412208&view=diff
==============================================================================
--- incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/integration/system/builder/SystemBuildersTestCase.java (original)
+++ incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/integration/system/builder/SystemBuildersTestCase.java Tue Jun  6 13:47:19 2006
@@ -6,7 +6,7 @@
 import org.apache.tuscany.core.component.WorkContextImpl;
 import org.apache.tuscany.core.component.event.CompositeStart;
 import org.apache.tuscany.core.component.event.CompositeStop;
-import org.apache.tuscany.core.component.scope.ModuleScopeContext;
+import org.apache.tuscany.core.component.scope.ModuleScopeContainer;
 import org.apache.tuscany.core.mock.component.Source;
 import org.apache.tuscany.core.mock.component.Target;
 import org.apache.tuscany.core.mock.factories.MockComponentFactory;
@@ -18,7 +18,7 @@
 import org.apache.tuscany.core.system.model.SystemImplementation;
 import org.apache.tuscany.spi.component.AtomicComponent;
 import org.apache.tuscany.spi.component.Reference;
-import org.apache.tuscany.spi.component.ScopeContext;
+import org.apache.tuscany.spi.component.ScopeContainer;
 import org.apache.tuscany.spi.component.Service;
 import org.apache.tuscany.spi.component.WorkContext;
 import org.apache.tuscany.spi.deployer.DeploymentContext;
@@ -39,7 +39,7 @@
      */
     public void testAtomicWireBuild() throws Exception {
         WorkContext work = new WorkContextImpl();
-        ScopeContext scope = new ModuleScopeContext(work);
+        ScopeContainer scope = new ModuleScopeContainer(work);
         scope.start();
 
         Connector connector = new ConnectorImpl();
@@ -75,7 +75,7 @@
      */
     public void testAtomicToReferenceWireBuild() throws Exception {
         WorkContext work = new WorkContextImpl();
-        ScopeContext scope = new ModuleScopeContext(work);
+        ScopeContainer scope = new ModuleScopeContainer(work);
         scope.start();
 
         Connector connector = new ConnectorImpl();
@@ -120,7 +120,7 @@
     @SuppressWarnings("unchecked")
     public void testServiceToAtomicWireBuild() throws Exception {
         WorkContext work = new WorkContextImpl();
-        ScopeContext scope = new ModuleScopeContext(work);
+        ScopeContainer scope = new ModuleScopeContainer(work);
         scope.start();
 
         ConnectorImpl connector = new ConnectorImpl();
@@ -161,7 +161,7 @@
     @SuppressWarnings("unchecked")
     public void testServiceToReferenceWireBuild() throws Exception {
 //        WorkContext work = new WorkContextImpl();
-//        ScopeContext scope = new ModuleScopeContext(work);
+//        ScopeContainer scope = new ModuleScopeContainer(work);
 //        scope.start();
 //
 //        Connector connector = new ConnectorImpl();
@@ -202,7 +202,7 @@
 
     protected void setUp() throws Exception {
         super.setUp();
-        ModuleScopeContext moduleScope = new ModuleScopeContext();
+        ModuleScopeContainer moduleScope = new ModuleScopeContainer();
         moduleScope.start();
         deploymentContext = new DeploymentContext(null, null, moduleScope);
 

Modified: incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/mock/factories/MockContextFactory.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/mock/factories/MockContextFactory.java?rev=412208&r1=412207&r2=412208&view=diff
==============================================================================
--- incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/mock/factories/MockContextFactory.java (original)
+++ incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/mock/factories/MockContextFactory.java Tue Jun  6 13:47:19 2006
@@ -24,7 +24,7 @@
 import org.apache.tuscany.spi.ObjectFactory;
 import org.apache.tuscany.spi.QualifiedName;
 import org.apache.tuscany.spi.component.AtomicComponent;
-import org.apache.tuscany.spi.component.ScopeContext;
+import org.apache.tuscany.spi.component.ScopeContainer;
 import org.apache.tuscany.spi.wire.InboundInvocationChain;
 import org.apache.tuscany.spi.wire.InboundWire;
 import org.osoa.sca.annotations.Destroy;
@@ -38,8 +38,8 @@
     private MockContextFactory() {
     }
 
-    public static Map<String, AtomicComponent> createWiredContexts(String source, Class<?> sourceClass, ScopeContext sourceScopeCtx,
-                                                                   String target, Class<?> targetClass, ScopeContext targetScopeCtx) throws NoSuchMethodException {
+    public static Map<String, AtomicComponent> createWiredContexts(String source, Class<?> sourceClass, ScopeContainer sourceScopeCtx,
+                                                                   String target, Class<?> targetClass, ScopeContainer targetScopeCtx) throws NoSuchMethodException {
         List<Class<?>> sourceClasses = new ArrayList<Class<?>>();
         sourceClasses.add(sourceClass);
         return createWiredContexts(source, sourceClasses, sourceClass, sourceScopeCtx, target, targetClass, targetScopeCtx);
@@ -55,10 +55,10 @@
     public static Map<String, AtomicComponent> createWiredContexts(String source,
                                                                    List<Class<?>> sourceInterfaces,
                                                                    Class<?> sourceClass,
-                                                                   ScopeContext sourceScopeCtx,
+                                                                   ScopeContainer sourceScopeCtx,
                                                                    String target,
                                                                    Class<?> targetClass,
-                                                                   ScopeContext targetScopeCtx) throws NoSuchMethodException {
+                                                                   ScopeContainer targetScopeCtx) throws NoSuchMethodException {
 
         Map<String, AtomicComponent> contexts = new HashMap<String, AtomicComponent>();
         SystemAtomicComponent targetCtx = createSystemAtomicContext(target, targetScopeCtx, targetClass);//, targetEager, targetInitInvoker, targetDestroyInvoker, null);
@@ -98,18 +98,18 @@
         return contexts;
     }
 
-    public static SystemAtomicComponent createSystemAtomicContext(String name, ScopeContext scopeContext, Class<?> clazz) throws NoSuchMethodException {
+    public static SystemAtomicComponent createSystemAtomicContext(String name, ScopeContainer scopeContainer, Class<?> clazz) throws NoSuchMethodException {
         List<Class<?>> serviceInterfaces = new ArrayList<Class<?>>();
         serviceInterfaces.add(clazz);
-        return createSystemAtomicContext(name, scopeContext, serviceInterfaces, clazz);
+        return createSystemAtomicContext(name, scopeContainer, serviceInterfaces, clazz);
     }
 
-    public static SystemAtomicComponent createSystemAtomicContext(String name, ScopeContext scopeContext, List<Class<?>> interfaces, Class<?> clazz) throws NoSuchMethodException {
-        return createSystemAtomicContext(name, scopeContext, interfaces, clazz, null, null);
+    public static SystemAtomicComponent createSystemAtomicContext(String name, ScopeContainer scopeContainer, List<Class<?>> interfaces, Class<?> clazz) throws NoSuchMethodException {
+        return createSystemAtomicContext(name, scopeContainer, interfaces, clazz, null, null);
     }
 
     public static SystemAtomicComponent createSystemAtomicContext(String name,
-                                                                  ScopeContext scopeContext,
+                                                                  ScopeContainer scopeContainer,
                                                                   List<Class<?>> serviceInterfaces,
                                                                   Class<?> clazz,
                                                                   List<Injector> injectors,
@@ -128,7 +128,7 @@
                 destroyInvoker = new MethodEventInvoker<Object>(method);
             }
         }
-        return createSystemAtomicContext(name, scopeContext, serviceInterfaces, clazz, eager, initInvoker, destroyInvoker, injectors, members);
+        return createSystemAtomicContext(name, scopeContainer, serviceInterfaces, clazz, eager, initInvoker, destroyInvoker, injectors, members);
     }
 
     /**
@@ -143,7 +143,7 @@
      * @throws NoSuchMethodException
      */
     public static SystemAtomicComponentImpl createSystemAtomicContext(String name,
-                                                                      ScopeContext scopeContext,
+                                                                      ScopeContainer scopeContainer,
                                                                       List<Class<?>> serviceInterfaces,
                                                                       Class<?> clazz,
                                                                       boolean eagerInit,
@@ -151,7 +151,7 @@
                                                                       EventInvoker<Object> destroyInvoker,
                                                                       List<Injector> injectors,
                                                                       Map<String, Member> members) throws NoSuchMethodException {
-        return new SystemAtomicComponentImpl(name, null, scopeContext, serviceInterfaces, createObjectFactory(clazz), eagerInit, initInvoker, destroyInvoker, injectors, members);
+        return new SystemAtomicComponentImpl(name, null, scopeContainer, serviceInterfaces, createObjectFactory(clazz), eagerInit, initInvoker, destroyInvoker, injectors, members);
     }
 
     public static <T> InboundWire<T> createTargetWireFactory(String serviceName, Class<T> interfaze) {

Modified: incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/system/component/ChildLocateTestCase.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/system/component/ChildLocateTestCase.java?rev=412208&r1=412207&r2=412208&view=diff
==============================================================================
--- incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/system/component/ChildLocateTestCase.java (original)
+++ incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/system/component/ChildLocateTestCase.java Tue Jun  6 13:47:19 2006
@@ -9,17 +9,17 @@
 
     public void testChildLocate() throws Exception {
 //         WorkContext workContext = new WorkContextImpl();
-//         ModuleScopeContext scopeContext = new ModuleScopeContext(workContext);
-//         scopeContext.start();
+//         ModuleScopeContainer scopeContainer = new ModuleScopeContainer(workContext);
+//         scopeContainer.start();
 //         SystemCompositeComponent parent = new SystemCompositeComponentImpl("parent", null, null);
 //         SystemCompositeComponent child1 = new SystemCompositeComponentImpl("child1", null, null);
 //         child1.setParent(parent);
 //         parent.registerContext(child1);
 //         parent.start();
 //         SystemAtomicComponent context = MockContextFactory.createSystemAtomicContext("source", SourceImpl.class);
-//         scopeContext.register(context);
-//         context.setScopeContext(scopeContext);
-//         scopeContext.publish(new CompositeStart(this, parent));
+//         scopeContainer.register(context);
+//         context.setScopeContext(scopeContainer);
+//         scopeContainer.publish(new CompositeStart(this, parent));
 //
 //         assertNotNull(source);
 //         CompositeComponent composite1 = (CompositeComponent) parent.getContext("child1");
@@ -27,9 +27,9 @@
 //         AtomicComponent ctx2 = (AtomicComponent) composite2.getContext("source");
 //         Source source2 = (Source) ctx2.getInstance();
 //         assertSame(source, source2);
-//         scopeContext.onEvent(new CompositeStop(this, parent));
+//         scopeContainer.onEvent(new CompositeStop(this, parent));
 //         parent.stop();
-//         scopeContext.stop();
+//         scopeContainer.stop();
 /////
 
 //        system.start();

Modified: incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/system/wire/AtomicComponentWireInvocationTestCase.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/system/wire/AtomicComponentWireInvocationTestCase.java?rev=412208&r1=412207&r2=412208&view=diff
==============================================================================
--- incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/system/wire/AtomicComponentWireInvocationTestCase.java (original)
+++ incubator/tuscany/sandbox/jboynes/sca/core2/src/test/java/org/apache/tuscany/core/system/wire/AtomicComponentWireInvocationTestCase.java Tue Jun  6 13:47:19 2006
@@ -6,7 +6,7 @@
 import java.util.List;
 import java.util.Map;
 
-import org.apache.tuscany.core.component.scope.ModuleScopeContext;
+import org.apache.tuscany.core.component.scope.ModuleScopeContainer;
 import org.apache.tuscany.core.mock.component.Source;
 import org.apache.tuscany.core.mock.component.SourceImpl;
 import org.apache.tuscany.core.mock.component.Target;
@@ -26,7 +26,7 @@
 public class AtomicComponentWireInvocationTestCase extends MockObjectTestCase {
 
     public void testWireResolution() throws NoSuchMethodException {
-        ModuleScopeContext scope = new ModuleScopeContext(null);
+        ModuleScopeContainer scope = new ModuleScopeContainer(null);
         scope.start();
         Target target = new TargetImpl();
         Mock mockWire = mock(SystemInboundWire.class);

Modified: incubator/tuscany/sandbox/jboynes/sca/spi/src/main/java/org/apache/tuscany/spi/component/AtomicComponent.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/sandbox/jboynes/sca/spi/src/main/java/org/apache/tuscany/spi/component/AtomicComponent.java?rev=412208&r1=412207&r2=412208&view=diff
==============================================================================
--- incubator/tuscany/sandbox/jboynes/sca/spi/src/main/java/org/apache/tuscany/spi/component/AtomicComponent.java (original)
+++ incubator/tuscany/sandbox/jboynes/sca/spi/src/main/java/org/apache/tuscany/spi/component/AtomicComponent.java Tue Jun  6 13:47:19 2006
@@ -46,7 +46,7 @@
 
     /**
      * Creates a new implementation instance, generally used as a callback by a {@link
-     * org.apache.tuscany.spi.component.ScopeContext}
+     * org.apache.tuscany.spi.component.ScopeContainer}
      *
      * @throws ObjectCreationException
      */

Modified: incubator/tuscany/sandbox/jboynes/sca/spi/src/main/java/org/apache/tuscany/spi/component/CompositeComponent.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/sandbox/jboynes/sca/spi/src/main/java/org/apache/tuscany/spi/component/CompositeComponent.java?rev=412208&r1=412207&r2=412208&view=diff
==============================================================================
--- incubator/tuscany/sandbox/jboynes/sca/spi/src/main/java/org/apache/tuscany/spi/component/CompositeComponent.java (original)
+++ incubator/tuscany/sandbox/jboynes/sca/spi/src/main/java/org/apache/tuscany/spi/component/CompositeComponent.java Tue Jun  6 13:47:19 2006
@@ -63,7 +63,7 @@
     List<Reference> getReferences();
 
     /**
-     * @param scopeContext
+     * @param scopeContainer
      */
-    void setScopeContext(ScopeContext scopeContext);
+    void setScopeContext(ScopeContainer scopeContainer);
 }

Modified: incubator/tuscany/sandbox/jboynes/sca/spi/src/main/java/org/apache/tuscany/spi/component/InstanceWrapper.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/sandbox/jboynes/sca/spi/src/main/java/org/apache/tuscany/spi/component/InstanceWrapper.java?rev=412208&r1=412207&r2=412208&view=diff
==============================================================================
--- incubator/tuscany/sandbox/jboynes/sca/spi/src/main/java/org/apache/tuscany/spi/component/InstanceWrapper.java (original)
+++ incubator/tuscany/sandbox/jboynes/sca/spi/src/main/java/org/apache/tuscany/spi/component/InstanceWrapper.java Tue Jun  6 13:47:19 2006
@@ -20,7 +20,7 @@
 
 /**
  * Provides lifecycle management for an implementation instance associated with an {@link AtomicComponent} for
- * use by the atomic context's associated {@link ScopeContext}
+ * use by the atomic context's associated {@link ScopeContainer}
  *
  * @version $Rev$ $Date$
  */

Copied: incubator/tuscany/sandbox/jboynes/sca/spi/src/main/java/org/apache/tuscany/spi/component/ScopeContainer.java (from r412206, incubator/tuscany/sandbox/jboynes/sca/spi/src/main/java/org/apache/tuscany/spi/component/ScopeContext.java)
URL: http://svn.apache.org/viewvc/incubator/tuscany/sandbox/jboynes/sca/spi/src/main/java/org/apache/tuscany/spi/component/ScopeContainer.java?p2=incubator/tuscany/sandbox/jboynes/sca/spi/src/main/java/org/apache/tuscany/spi/component/ScopeContainer.java&p1=incubator/tuscany/sandbox/jboynes/sca/spi/src/main/java/org/apache/tuscany/spi/component/ScopeContext.java&r1=412206&r2=412208&rev=412208&view=diff
==============================================================================
--- incubator/tuscany/sandbox/jboynes/sca/spi/src/main/java/org/apache/tuscany/spi/component/ScopeContext.java (original)
+++ incubator/tuscany/sandbox/jboynes/sca/spi/src/main/java/org/apache/tuscany/spi/component/ScopeContainer.java Tue Jun  6 13:47:19 2006
@@ -27,7 +27,7 @@
  * @version $Rev$ $Date$
  * @see SCAObject
  */
-public interface ScopeContext extends Lifecycle, RuntimeEventListener {
+public interface ScopeContainer extends Lifecycle, RuntimeEventListener {
 
     /**
      * Returns the scope value representing the scope context

Propchange: incubator/tuscany/sandbox/jboynes/sca/spi/src/main/java/org/apache/tuscany/spi/component/ScopeContainer.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/tuscany/sandbox/jboynes/sca/spi/src/main/java/org/apache/tuscany/spi/component/ScopeContainer.java
------------------------------------------------------------------------------
    svn:keywords = Rev Date

Modified: incubator/tuscany/sandbox/jboynes/sca/spi/src/main/java/org/apache/tuscany/spi/component/ScopeRegistry.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/sandbox/jboynes/sca/spi/src/main/java/org/apache/tuscany/spi/component/ScopeRegistry.java?rev=412208&r1=412207&r2=412208&view=diff
==============================================================================
--- incubator/tuscany/sandbox/jboynes/sca/spi/src/main/java/org/apache/tuscany/spi/extension/AtomicComponentExtension.java (original)
+++ incubator/tuscany/sandbox/jboynes/sca/spi/src/main/java/org/apache/tuscany/spi/extension/AtomicComponentExtension.java Tue Jun  6 13:47:19 2006
@@ -9,7 +9,7 @@
 import org.apache.tuscany.spi.component.AbstractSCAObject;
 import org.apache.tuscany.spi.component.AtomicComponent;
 import org.apache.tuscany.spi.component.CompositeComponent;
-import org.apache.tuscany.spi.component.ScopeContext;
+import org.apache.tuscany.spi.component.ScopeContainer;
 import org.apache.tuscany.spi.component.TargetException;
 import org.apache.tuscany.spi.model.Scope;
 import org.apache.tuscany.spi.wire.InboundInvocationChain;
@@ -24,15 +24,15 @@
  */
 public abstract class AtomicComponentExtension<T> extends AbstractSCAObject<T> implements AtomicComponent<T> {
 
-    protected ScopeContext scopeContext;
+    protected ScopeContainer scopeContainer;
     protected Scope scope;
     protected Map<String, InboundWire> serviceWires = new HashMap<String, InboundWire>();
     protected Map<String, List<OutboundWire>> referenceWires = new HashMap<String, List<OutboundWire>>();
     protected WireService wireService;
 
-    protected AtomicComponentExtension(String name, CompositeComponent<?> parent, ScopeContext scopeContext, WireService wireService) {
+    protected AtomicComponentExtension(String name, CompositeComponent<?> parent, ScopeContainer scopeContainer, WireService wireService) {
         super(name, parent);
-        this.scopeContext = scopeContext;
+        this.scopeContainer = scopeContainer;
         this.wireService = wireService;
     }
 
@@ -46,7 +46,7 @@
 
     public void start() throws CoreRuntimeException {
         super.start();
-        scopeContext.register(this);
+        scopeContainer.register(this);
     }
 
     public void init(Object instance) throws TargetException {



---------------------------------------------------------------------
To unsubscribe, e-mail: tuscany-commits-unsubscribe@ws.apache.org
For additional commands, e-mail: tuscany-commits-help@ws.apache.org
--- incubator/tuscany/sandbox/jboynes/sca/spi/src/main/java/org/apache/tuscany/spi/component/ScopeRegistry.java (original)
+++ incubator/tuscany/sandbox/jboynes/sca/spi/src/main/java/org/apache/tuscany/spi/component/ScopeRegistry.java Tue Jun  6 13:47:19 2006
@@ -17,15 +17,15 @@
 import org.apache.tuscany.spi.model.Scope;
 
 /**
  * Manages {@link ScopeContext}s in the runtime
  *
  * @version $$Rev$$ $$Date$$
  */
 public interface ScopeRegistry {
 
-    ScopeContext getScopeContext(Scope scope) throws ScopeNotFoundException;
+    ScopeContainer getScopeContainer(Scope scope) throws ScopeNotFoundException;
 
-    <T extends ScopeContext> void registerFactory(Scope scope, ObjectFactory<T> factory);
+    <T extends ScopeContainer> void registerFactory(Scope scope, ObjectFactory<T> factory);
 
     void deregisterFactory(Scope scope);
 
@@ -17,15 +17,15 @@
 
 /**
- * Manages {@link ScopeContext}s in the runtime
+ * Manages {@link ScopeContainer}s in the runtime
  *
  * @version $$Rev$$ $$Date$$

Modified: incubator/tuscany/sandbox/jboynes/sca/spi/src/main/java/org/apache/tuscany/spi/deployer/DeploymentContext.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/sandbox/jboynes/sca/spi/src/main/java/org/apache/tuscany/spi/deployer/DeploymentContext.java?rev=412208&r1=412207&r2=412208&view=diff
==============================================================================
--- incubator/tuscany/sandbox/jboynes/sca/spi/src/main/java/org/apache/tuscany/spi/deployer/DeploymentContext.java (original)
+++ incubator/tuscany/sandbox/jboynes/sca/spi/src/main/java/org/apache/tuscany/spi/deployer/DeploymentContext.java Tue Jun  6 13:47:19 2006
@@ -18,7 +18,7 @@
 
 import javax.xml.stream.XMLInputFactory;
 
-import org.apache.tuscany.spi.component.ScopeContext;
+import org.apache.tuscany.spi.component.ScopeContainer;
 
 /**
  * An holder that can be used during the load process to store information that is not part of the logical
@@ -30,7 +30,7 @@
 public class DeploymentContext {
     private final ClassLoader classLoader;
     private final XMLInputFactory xmlFactory;
-    private final ScopeContext moduleScope;
+    private final ScopeContainer moduleScope;
 
     /**
      * Constructor specifying the loader for application resources.
@@ -39,7 +39,7 @@
      * @param xmlFactory  a factory that can be used to obtain an StAX XMLStreamReader
      * @param moduleScope the scope context representing this deployment's MODULE scope
      */
-    public DeploymentContext(ClassLoader classLoader, XMLInputFactory xmlFactory, ScopeContext moduleScope) {
+    public DeploymentContext(ClassLoader classLoader, XMLInputFactory xmlFactory, ScopeContainer moduleScope) {
         this.classLoader = classLoader;
         this.xmlFactory = xmlFactory;
         this.moduleScope = moduleScope;
@@ -64,11 +64,11 @@
     }
 
     /**
      * Returns the ScopeContext for the MODULE scope that will be associated with this deployment unit.
      *
      * @return the ScopeContext for the MODULE scope that will be associated with this deployment unit
      */
-    public ScopeContext getModuleScope() {
+    public ScopeContainer getModuleScope() {
         return moduleScope;
     }
 }
@@ -64,11 +64,11 @@
 
     /**
-     * Returns the ScopeContext for the MODULE scope that will be associated with this deployment unit.
+     * Returns the ScopeContainer for the MODULE scope that will be associated with this deployment unit.
      *
@@ -64,11 +64,11 @@
      *
-     * @return the ScopeContext for the MODULE scope that will be associated with this deployment unit
+     * @return the ScopeContainer for the MODULE scope that will be associated with this deployment unit
      */

Modified: incubator/tuscany/sandbox/jboynes/sca/spi/src/main/java/org/apache/tuscany/spi/extension/AtomicComponentExtension.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/sandbox/jboynes/sca/spi/src/main/java/org/apache/tuscany/spi/extension/AtomicComponentExtension.java?rev=412208&r1=412207&r2=412208&view=diff
==============================================================================